#[non_exhaustive]pub enum ComponentType {
Show 20 variants
ActionRow,
Button,
TextSelectMenu,
TextInput,
UserSelectMenu,
RoleSelectMenu,
MentionableSelectMenu,
ChannelSelectMenu,
Section,
TextDisplay,
Thumbnail,
MediaGallery,
File,
Separator,
Container,
Label,
FileUpload,
CheckboxGroup,
Checkbox,
Unknown(u8),
}Expand description
Type of Component.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ActionRow
Component is an ActionRow.
Button
Component is an Button.
TextSelectMenu
Component is a SelectMenu with custom string options.
TextInput
Component is an TextInput.
UserSelectMenu
Component is a SelectMenu for users.
RoleSelectMenu
Component is a SelectMenu for roles.
MentionableSelectMenu
Component is a SelectMenu for mentionables.
ChannelSelectMenu
Component is a SelectMenu for channels.
Section
Component is a Container to display text alongside an accessory component.
TextDisplay
Component is a TextDisplay containing markdown text.
Thumbnail
Component is a Thumbnail that can be used as an accessory.
MediaGallery
Component is a MediaGallery that displays images and other media.
File
Component is a FileDisplay that displays an attached file.
Separator
Component is a Separator that adds vertical padding between other components.
Container
Component is a Container that visually groups a set of components.
Label
Component is a Label that provides a label and an optional description
for modal components.
FileUpload
Component is a FileUpload that allows uploading files in modals.
CheckboxGroup
Component is a CheckboxGroup that allows for a group of selectable checkboxes in modals
Checkbox
Component is a Checkbox that allows for a selectable checkbox in modals
Unknown(u8)
Variant value is unknown to the library.
Implementations