pub struct Checkbox {
pub custom_id: String,
pub default: Option<bool>,
pub id: Option<i32>,
}Expand description
A component allowing a checkbox in a modal.
checkboxes are only available in modals and must be placed inside a label.
Fields’ default values may be used by setting them to None.
Fields
custom_id: StringDeveloper defined identifier.
Must be between 1-100 characters
default: Option<bool>Whether the checkbox is selected by default.
Set to false if None is given
id: Option<i32>Optional identifier for the component.